@@ -67,8 +67,12 @@ class Module:
         '''
         _bf_limit = 50
         _ss_limit = 50
-        self.biological_features = tuple(biofeatures)
-        self.sample_sets = tuple(samplesets)
+        self.biological_features = tuple()
+        self.sample_sets = tuple()
+        if biofeatures:
+            self.biological_features = tuple(biofeatures)
+        if samplesets:
+            self.sample_sets = tuple(samplesets)
         self.name = None
         self.id = None
         # check that everything is ok to retrieve the normalized values
